@@ -74,7 +74,7 @@ def compute_alpha_signal_lo(df=None, core_tokens=['BTC', 'ETH'], extra_tokens=['
                         data={'S{}'.format('ETH'): strat_daily_ETH(df, 'close_ETH', rebalancing_day=rebalancing_day)})
     weekly = weekly.join(addw, how='left')
     for i in extra_tokens:
-        addw = pd.DataFrame(index=df.index, data={'S{}'.format(i): strat_daily_BTC(df, f'close_{i}')})
+        addw = pd.DataFrame(index=df.index, data={'S{}'.format(i): strat_daily_BTC(df, f'close_{i}', rebalancing_day=rebalancing_day)})
         weekly = weekly.join(addw, how='left')
     dfsig = weekly.copy()
     dfsig2 = dfsig.copy()
